@@ -4,7 +4,7 @@ use num::Zero;
 
 /// Description of a motor applied to a joint.
 #[derive(Copy, Clone, Debug)]
-pub struct JointMotor<V, N: RealField> {
+pub struct JointMotor<V, N: RealField + Copy> {
     /// The velocity the motor will attempt to reach.
     pub desired_velocity: V,
     /// The maximum velocity the motor will attempt to reach.
@@ -15,7 +15,7 @@ pub struct JointMotor<V, N: RealField> {
     pub enabled: bool,
 }
 
-impl<V: Zero, N: RealField> JointMotor<V, N> {
+impl<V: Zero, N: RealField + Copy> JointMotor<V, N> {
     /// Create a disable motor with zero desired velocity.
     ///
     /// The max force is initialized to a virtually infinite value, i.e., `N::max_value()`.
@@ -37,7 +37,7 @@ impl<V: Zero, N: RealField> JointMotor<V, N> {
     }
 }
 
-impl<V: Zero, N: RealField> Default for JointMotor<V, N> {
+impl<V: Zero, N: RealField + Copy> Default for JointMotor<V, N> {
     fn default() -> Self {
         Self::new()
     }
