@@ -17,7 +17,7 @@ use crate::utils::{UserData, UserDataBox};
 
 /// Description of the way a collider is attached to a body.
 #[derive(Clone)]
-pub enum ColliderAnchor<N: RealField, Handle: BodyHandle> {
+pub enum ColliderAnchor<N: RealField + Copy, Handle: BodyHandle> {
     /// Attach of a collider with a body part.
     OnBodyPart {
         /// The attached body part handle.
@@ -37,7 +37,7 @@ pub enum ColliderAnchor<N: RealField, Handle: BodyHandle> {
     },
 }
 
-impl<N: RealField, Handle: BodyHandle> ColliderAnchor<N, Handle> {
+impl<N: RealField + Copy, Handle: BodyHandle> ColliderAnchor<N, Handle> {
     /// The body this anchor is attached to.
     #[inline]
     pub fn body(&self) -> Handle {
@@ -49,7 +49,7 @@ impl<N: RealField, Handle: BodyHandle> ColliderAnchor<N, Handle> {
 }
 
 /// The data a collider set must return after a collider has been removed.
-pub struct ColliderRemovalData<N: RealField, Handle: BodyHandle> {
+pub struct ColliderRemovalData<N: RealField + Copy, Handle: BodyHandle> {
     pub(crate) anchor: ColliderAnchor<N, Handle>,
     pub(crate) shape: ShapeHandle<N>,
     pub(crate) density: N,
@@ -60,7 +60,7 @@ pub struct ColliderRemovalData<N: RealField, Handle: BodyHandle> {
 /// Data stored in each collider.
 ///
 /// This is needed by nphysics.
-pub struct ColliderData<N: RealField, Handle: BodyHandle> {
+pub struct ColliderData<N: RealField + Copy, Handle: BodyHandle> {
     margin: N,
     density: N,
     anchor: ColliderAnchor<N, Handle>,
@@ -71,7 +71,7 @@ pub struct ColliderData<N: RealField, Handle: BodyHandle> {
     user_data: Option<Box<dyn Any + Send + Sync>>,
 }
 
-impl<N: RealField, Handle: BodyHandle> ColliderData<N, Handle> {
+impl<N: RealField + Copy, Handle: BodyHandle> ColliderData<N, Handle> {
     /// Initializes data for a collider.
     pub fn new(
         margin: N,
@@ -162,11 +162,11 @@ impl<N: RealField, Handle: BodyHandle> ColliderData<N, Handle> {
 
 /// A geometric entity that can be attached to a body so it can be affected by contacts and proximity queries.
 #[repr(transparent)]
-pub struct Collider<N: RealField, Handle: BodyHandle>(
+pub struct Collider<N: RealField + Copy, Handle: BodyHandle>(
     pub(crate) CollisionObject<N, ColliderData<N, Handle>>,
 ); // FIXME: keep this pub(crate) or private?
 
-impl<N: RealField, Handle: BodyHandle> Collider<N, Handle> {
+impl<N: RealField + Copy, Handle: BodyHandle> Collider<N, Handle> {
     /// Computes the data that needs to be returned once this collider has been removed from a collider set.
     pub fn removal_data(&self) -> Option<ColliderRemovalData<N, Handle>> {
         Some(ColliderRemovalData {
@@ -401,7 +401,7 @@ impl<N: RealField, Handle: BodyHandle> Collider<N, Handle> {
     }
 }
 
-impl<N: RealField, Handle: BodyHandle> CollisionObjectRef<N> for Collider<N, Handle> {
+impl<N: RealField + Copy, Handle: BodyHandle> CollisionObjectRef<N> for Collider<N, Handle> {
     fn graph_index(&self) -> Option<CollisionObjectGraphIndex> {
         self.0.graph_index()
     }
@@ -438,7 +438,7 @@ impl<N: RealField, Handle: BodyHandle> CollisionObjectRef<N> for Collider<N, Han
 /// A non-deformable collider builder.
 ///
 /// See https://www.nphysics.org/rigid_body_simulations_with_contacts/#colliders for details.
-pub struct ColliderDesc<N: RealField> {
+pub struct ColliderDesc<N: RealField + Copy> {
     user_data: Option<UserDataBox>,
     margin: N,
     collision_groups: CollisionGroups,
@@ -452,7 +452,7 @@ pub struct ColliderDesc<N: RealField> {
     ccd_enabled: bool,
 }
 
-impl<N: RealField> ColliderDesc<N> {
+impl<N: RealField + Copy> ColliderDesc<N> {
     /// Creates a new collider builder with the given shape.
     pub fn new(shape: ShapeHandle<N>) -> Self {
         let linear_prediction = na::convert(0.001);
@@ -573,7 +573,7 @@ impl<N: RealField> ColliderDesc<N> {
 }
 
 /// A deformable collider builder.
-pub struct DeformableColliderDesc<N: RealField> {
+pub struct DeformableColliderDesc<N: RealField + Copy> {
     user_data: Option<UserDataBox>,
     margin: N,
     collision_groups: CollisionGroups,
@@ -586,7 +586,7 @@ pub struct DeformableColliderDesc<N: RealField> {
     body_parts_mapping: Option<Arc<Vec<usize>>>,
 }
 
-impl<N: RealField> DeformableColliderDesc<N> {
+impl<N: RealField + Copy> DeformableColliderDesc<N> {
     /// Creates a deformable collider from the given shape.
     ///
     /// Panics if the shape is not deformable.
@@ -613,7 +613,7 @@ impl<N: RealField> DeformableColliderDesc<N> {
     }
 }
 
-impl<N: RealField> DeformableColliderDesc<N> {
+impl<N: RealField + Copy> DeformableColliderDesc<N> {
     user_data_desc_accessors!();
 
     /// Sets the shape of this collider builder.
