@@ -15,7 +15,7 @@ use crate::math::{Dim, Isometry, Point, Velocity, DIM};
 use crate::object::BodyStatus;
 use crate::solver::ForceDirection;
 
-pub(crate) fn elasticity_coefficients<N: RealField>(
+pub(crate) fn elasticity_coefficients<N: RealField + Copy>(
     young_modulus: N,
     poisson_ratio: N,
 ) -> (N, N, N) {
@@ -65,7 +65,7 @@ impl FiniteElementIndices {
 }
 
 #[inline]
-pub(crate) fn velocity_at_point<N: RealField>(
+pub(crate) fn velocity_at_point<N: RealField + Copy>(
     indices: FiniteElementIndices,
     positions: &DVector<N>,
     velocities: &DVector<N>,
@@ -96,7 +96,7 @@ pub(crate) fn velocity_at_point<N: RealField>(
 }
 
 #[inline]
-pub(crate) fn world_point_at_material_point<N: RealField>(
+pub(crate) fn world_point_at_material_point<N: RealField + Copy>(
     indices: FiniteElementIndices,
     positions: &DVector<N>,
     point: &Point<N>,
@@ -133,7 +133,7 @@ pub(crate) fn world_point_at_material_point<N: RealField>(
 // because it makes it simpler to handle the case where we don't know at compile-time the
 // dimension of `indices`.
 #[inline]
-pub(crate) fn material_point_at_world_point<N: RealField>(
+pub(crate) fn material_point_at_world_point<N: RealField + Copy>(
     indices: FiniteElementIndices,
     positions: &DVector<N>,
     point: &Point<N>,
@@ -197,7 +197,7 @@ pub(crate) fn material_point_at_world_point<N: RealField>(
 }
 
 #[inline]
-pub(crate) fn fill_contact_geometry_fem<N: RealField>(
+pub(crate) fn fill_contact_geometry_fem<N: RealField + Copy>(
     ndofs: usize,
     status: BodyStatus,
     indices: FiniteElementIndices,
