@@ -30,13 +30,13 @@ use crate::utils::{UserData, UserDataBox};
 
 /// An element of the mass-spring system.
 #[derive(Clone)]
-pub struct MassSpringElement<N: RealField> {
+pub struct MassSpringElement<N: RealField + Copy> {
     indices: FiniteElementIndices,
     phantom: PhantomData<N>,
 }
 
 #[derive(Clone)]
-struct Spring<N: RealField> {
+struct Spring<N: RealField + Copy> {
     nodes: (usize, usize),
     // Should be Unit<Vector<N>>, but can be zero.
     dir: Unit<Vector<N>>,
@@ -47,7 +47,7 @@ struct Spring<N: RealField> {
     plastic_strain: N,
 }
 
-impl<N: RealField> Spring<N> {
+impl<N: RealField + Copy> Spring<N> {
     fn from_positions(
         nodes: (usize, usize),
         positions: &[N],
@@ -71,7 +71,7 @@ impl<N: RealField> Spring<N> {
 }
 
 /// A deformable surface using a mass-spring model with triangular elements.
-pub struct MassSpringSystem<N: RealField> {
+pub struct MassSpringSystem<N: RealField + Copy> {
     springs: Vec<Spring<N>>,
     elements: Vec<MassSpringElement<N>>,
     kinematic_nodes: DVector<bool>,
@@ -107,7 +107,7 @@ fn key(i: usize, j: usize) -> (usize, usize) {
     }
 }
 
-impl<N: RealField> MassSpringSystem<N> {
+impl<N: RealField + Copy> MassSpringSystem<N> {
     /// Creates a new deformable surface following the mass-spring model.
     ///
     /// The surface is initialized with a set of links corresponding to each trimesh edges.
@@ -523,7 +523,7 @@ impl<N: RealField> MassSpringSystem<N> {
     }
 }
 
-impl<N: RealField> Body<N> for MassSpringSystem<N> {
+impl<N: RealField + Copy> Body<N> for MassSpringSystem<N> {
     #[inline]
     fn gravity_enabled(&self) -> bool {
         self.gravity_enabled
@@ -888,7 +888,7 @@ impl<N: RealField> Body<N> for MassSpringSystem<N> {
     }
 }
 
-impl<N: RealField> BodyPart<N> for MassSpringElement<N> {
+impl<N: RealField + Copy> BodyPart<N> for MassSpringElement<N> {
     fn center_of_mass(&self) -> Point<N> {
         unimplemented!()
     }
@@ -914,7 +914,7 @@ impl<N: RealField> BodyPart<N> for MassSpringElement<N> {
     }
 }
 
-enum MassSpringSystemDescGeometry<'a, N: RealField> {
+enum MassSpringSystemDescGeometry<'a, N: RealField + Copy> {
     Quad(usize, usize),
     Polyline(&'a Polyline<N>),
     #[cfg(feature = "dim3")]
@@ -922,7 +922,7 @@ enum MassSpringSystemDescGeometry<'a, N: RealField> {
 }
 
 /// A builder for mass-spring systems.
-pub struct MassSpringSystemDesc<'a, N: RealField> {
+pub struct MassSpringSystemDesc<'a, N: RealField + Copy> {
     user_data: Option<UserDataBox>,
     geom: MassSpringSystemDescGeometry<'a, N>,
     stiffness: N,
@@ -935,7 +935,7 @@ pub struct MassSpringSystemDesc<'a, N: RealField> {
     gravity_enabled: bool,
 }
 
-impl<'a, N: RealField> MassSpringSystemDesc<'a, N> {
+impl<'a, N: RealField + Copy> MassSpringSystemDesc<'a, N> {
     fn with_geometry(geom: MassSpringSystemDescGeometry<'a, N>) -> Self {
         MassSpringSystemDesc {
             user_data: None,
