@@ -23,7 +23,7 @@ use crate::utils::GeneralizedCross;
 
 /// A rigid body.
 #[derive(Debug)]
-pub struct RigidBody<N: RealField> {
+pub struct RigidBody<N: RealField + Copy> {
     position0: Isometry<N>,
     position: Isometry<N>,
     velocity: Velocity<N>,
@@ -49,7 +49,7 @@ pub struct RigidBody<N: RealField> {
     user_data: Option<Box<dyn Any + Send + Sync>>,
 }
 
-impl<N: RealField> RigidBody<N> {
+impl<N: RealField + Copy> RigidBody<N> {
     /// Create a new rigid body with the specified position.
     fn new(position: Isometry<N>) -> Self {
         let inertia = Inertia::zero();
@@ -381,7 +381,7 @@ impl<N: RealField> RigidBody<N> {
     }
 }
 
-impl<N: RealField> Body<N> for RigidBody<N> {
+impl<N: RealField + Copy> Body<N> for RigidBody<N> {
     #[inline]
     fn activation_status(&self) -> &ActivationStatus<N> {
         &self.activation
@@ -884,7 +884,7 @@ impl<N: RealField> Body<N> for RigidBody<N> {
     }
 }
 
-impl<N: RealField> BodyPart<N> for RigidBody<N> {
+impl<N: RealField + Copy> BodyPart<N> for RigidBody<N> {
     #[inline]
     fn is_ground(&self) -> bool {
         false
@@ -946,7 +946,7 @@ impl<N: RealField> BodyPart<N> for RigidBody<N> {
 /// `RigidBodyDesc` for the first time. The `.set_` methods are useful when modifying it after
 /// this initialization (including after calls to `.build`).
 #[derive(Clone)]
-pub struct RigidBodyDesc<N: RealField> {
+pub struct RigidBodyDesc<N: RealField + Copy> {
     user_data: Option<UserDataBox>,
     gravity_enabled: bool,
     linear_motion_interpolation_enabled: bool,
@@ -967,7 +967,7 @@ pub struct RigidBodyDesc<N: RealField> {
     kinematic_rotations: bool,
 }
 
-impl<'a, N: RealField> RigidBodyDesc<N> {
+impl<'a, N: RealField + Copy> RigidBodyDesc<N> {
     /// A default rigid body builder.
     pub fn new() -> RigidBodyDesc<N> {
         RigidBodyDesc {
