@@ -14,14 +14,14 @@ use crate::solver::{
 
 /// The direction of a force in world-space.
 #[derive(Copy, Clone, Debug)]
-pub enum ForceDirection<N: RealField> {
+pub enum ForceDirection<N: RealField + Copy> {
     /// A linear force toward a direction.
     Linear(Unit<Vector<N>>),
     /// A torque wrt. an axis.
     Angular(Unit<AngularVector<N>>),
 }
 
-impl<N: RealField> ForceDirection<N> {
+impl<N: RealField + Copy> ForceDirection<N> {
     /// The force (at the specified point) resulting from this unit force applied at the specified point.
     #[inline]
     pub fn at_point(&self, pt: &Point<N>) -> Force<N> {
@@ -32,7 +32,7 @@ impl<N: RealField> ForceDirection<N> {
     }
 }
 
-impl<N: RealField> Neg for ForceDirection<N> {
+impl<N: RealField + Copy> Neg for ForceDirection<N> {
     type Output = Self;
 
     #[inline]
@@ -50,7 +50,7 @@ impl<N: RealField> Neg for ForceDirection<N> {
 /// If the force is a torque, it is applied at the centers of mass of the body parts.
 /// Every input are expressed in world-space.
 #[inline]
-pub fn constraint_pair_geometry<N: RealField, B: ?Sized + Body<N>, H: BodyHandle>(
+pub fn constraint_pair_geometry<N: RealField + Copy, B: ?Sized + Body<N>, H: BodyHandle>(
     body1: &B,
     part1: &dyn BodyPart<N>,
     handle1: BodyPartHandle<H>,
@@ -137,7 +137,7 @@ pub fn constraint_pair_geometry<N: RealField, B: ?Sized + Body<N>, H: BodyHandle
 /// Test if a constraint between the two given bodies should be a ground
 /// constraint (a constraint between a dynamic body and one without any degree of freedom).
 #[inline]
-pub fn constraints_are_ground_constraints<N: RealField, B: ?Sized + Body<N>>(
+pub fn constraints_are_ground_constraints<N: RealField + Copy, B: ?Sized + Body<N>>(
     body1: &B,
     body2: &B,
 ) -> bool {
@@ -146,7 +146,7 @@ pub fn constraints_are_ground_constraints<N: RealField, B: ?Sized + Body<N>>(
 
 /// Retrieve the external velocity subvectors for the given bodies.
 #[inline(always)]
-pub fn split_ext_vels<'a, N: RealField, B: ?Sized + Body<N>>(
+pub fn split_ext_vels<'a, N: RealField + Copy, B: ?Sized + Body<N>>(
     body1: &B,
     body2: &B,
     assembly_id1: usize,
@@ -165,7 +165,7 @@ pub fn split_ext_vels<'a, N: RealField, B: ?Sized + Body<N>>(
 ///
 /// All inputs mut be given in world-space.
 pub fn cancel_relative_linear_velocity_wrt_axis<
-    N: RealField,
+    N: RealField + Copy,
     B: ?Sized + Body<N>,
     H: BodyHandle,
     Id,
@@ -244,7 +244,7 @@ pub fn cancel_relative_linear_velocity_wrt_axis<
 /// Generates velocity constraints to cancel the relative linear velocity of two body parts.
 ///
 /// All inputs mut be given in world-space.
-pub fn cancel_relative_linear_velocity<N: RealField, B: ?Sized + Body<N>, H: BodyHandle>(
+pub fn cancel_relative_linear_velocity<N: RealField + Copy, B: ?Sized + Body<N>, H: BodyHandle>(
     body1: &B,
     part1: &dyn BodyPart<N>,
     handle1: BodyPartHandle<H>,
@@ -295,7 +295,7 @@ pub fn cancel_relative_linear_velocity<N: RealField, B: ?Sized + Body<N>, H: Bod
 /// Generate position constraints to cancel the relative translation of two bodies wrt the given axis.
 ///
 /// All inputs mut be given in world-space.
-pub fn cancel_relative_translation_wrt_axis<N: RealField, B: ?Sized + Body<N>, H: BodyHandle>(
+pub fn cancel_relative_translation_wrt_axis<N: RealField + Copy, B: ?Sized + Body<N>, H: BodyHandle>(
     parameters: &IntegrationParameters<N>,
     body1: &B,
     part1: &dyn BodyPart<N>,
@@ -361,7 +361,7 @@ pub fn cancel_relative_translation_wrt_axis<N: RealField, B: ?Sized + Body<N>, H
 /// Generate position constraints to cancel the relative translation of two bodies.
 ///
 /// All inputs mut be given in world-space.
-pub fn cancel_relative_translation<N: RealField, B: ?Sized + Body<N>, H: BodyHandle>(
+pub fn cancel_relative_translation<N: RealField + Copy, B: ?Sized + Body<N>, H: BodyHandle>(
     parameters: &IntegrationParameters<N>,
     body1: &B,
     part1: &dyn BodyPart<N>,
@@ -420,7 +420,7 @@ pub fn cancel_relative_translation<N: RealField, B: ?Sized + Body<N>, H: BodyHan
 ///
 /// All inputs mut be given in world-space.
 pub fn cancel_relative_angular_velocity_wrt_axis<
-    N: RealField,
+    N: RealField + Copy,
     B: ?Sized + Body<N>,
     H: BodyHandle,
     Id,
@@ -499,7 +499,7 @@ pub fn cancel_relative_angular_velocity_wrt_axis<
 /// Generate velocity constraints to cancel the relative angular velocity of two bodies.
 ///
 /// All inputs mut be given in world-space.
-pub fn cancel_relative_angular_velocity<N: RealField, B: ?Sized + Body<N>, H: BodyHandle>(
+pub fn cancel_relative_angular_velocity<N: RealField + Copy, B: ?Sized + Body<N>, H: BodyHandle>(
     body1: &B,
     part1: &dyn BodyPart<N>,
     handle1: BodyPartHandle<H>,
@@ -550,7 +550,7 @@ pub fn cancel_relative_angular_velocity<N: RealField, B: ?Sized + Body<N>, H: Bo
 /// Generate position constraints to cancel the relative rotation of two bodies.
 ///
 /// All inputs mut be given in world-space.
-pub fn cancel_relative_rotation<N: RealField, B: ?Sized + Body<N>, H: BodyHandle>(
+pub fn cancel_relative_rotation<N: RealField + Copy, B: ?Sized + Body<N>, H: BodyHandle>(
     parameters: &IntegrationParameters<N>,
     body1: &B,
     part1: &dyn BodyPart<N>,
@@ -612,7 +612,7 @@ pub fn cancel_relative_rotation<N: RealField, B: ?Sized + Body<N>, H: BodyHandle
 /// All inputs mut be given in world-space.
 #[cfg(feature = "dim3")]
 pub fn restrict_relative_angular_velocity_to_axis<
-    N: RealField,
+    N: RealField + Copy,
     B: ?Sized + Body<N>,
     H: BodyHandle,
 >(
@@ -698,7 +698,7 @@ pub fn restrict_relative_angular_velocity_to_axis<
 ///
 /// All inputs mut be given in world-space.
 #[cfg(feature = "dim3")]
-pub fn align_axis<N: RealField, B: ?Sized + Body<N>, H: BodyHandle>(
+pub fn align_axis<N: RealField + Copy, B: ?Sized + Body<N>, H: BodyHandle>(
     parameters: &IntegrationParameters<N>,
     body1: &B,
     part1: &dyn BodyPart<N>,
@@ -769,7 +769,7 @@ pub fn align_axis<N: RealField, B: ?Sized + Body<N>, H: BodyHandle>(
 ///
 /// All inputs mut be given in world-space.
 pub fn restrict_relative_linear_velocity_to_axis<
-    N: RealField,
+    N: RealField + Copy,
     B: ?Sized + Body<N>,
     H: BodyHandle,
 >(
@@ -855,7 +855,7 @@ pub fn restrict_relative_linear_velocity_to_axis<
 /// Generate position constraints to project `anchor2` into the axis with direction `axis1` and passing through the `anchor1`.
 ///
 /// All inputs mut be given in world-space.
-pub fn project_anchor_to_axis<N: RealField, B: ?Sized + Body<N>, H: BodyHandle>(
+pub fn project_anchor_to_axis<N: RealField + Copy, B: ?Sized + Body<N>, H: BodyHandle>(
     parameters: &IntegrationParameters<N>,
     body1: &B,
     part1: &dyn BodyPart<N>,
@@ -918,7 +918,7 @@ pub fn project_anchor_to_axis<N: RealField, B: ?Sized + Body<N>, H: BodyHandle>(
 ///
 /// All inputs mut be given in world-space.
 #[cfg(feature = "dim3")]
-pub fn restore_angle_between_axis<N: RealField, B: ?Sized + Body<N>, H: BodyHandle>(
+pub fn restore_angle_between_axis<N: RealField + Copy, B: ?Sized + Body<N>, H: BodyHandle>(
     parameters: &IntegrationParameters<N>,
     body1: &B,
     part1: &dyn BodyPart<N>,
