@@ -23,13 +23,13 @@ use crate::world::{BroadPhasePairFilterSets, GeometricalWorld};
 /// The default mechanical world, that can be used with a `DefaultBodyHandle` and `DefaultColliderHandle`.
 pub type DefaultMechanicalWorld<N> = MechanicalWorld<N, DefaultBodyHandle, DefaultColliderHandle>;
 
-enum PredictedImpacts<N: RealField, Handle: BodyHandle, CollHandle: ColliderHandle> {
+enum PredictedImpacts<N: RealField + Copy, Handle: BodyHandle, CollHandle: ColliderHandle> {
     Impacts(Vec<TOIEntry<N, Handle, CollHandle>>, HashMap<Handle, N>),
     ImpactsAfterEndTime(N),
     NoImpacts,
 }
 
-impl<N: RealField, Handle: BodyHandle, CollHandle: ColliderHandle>
+impl<N: RealField + Copy, Handle: BodyHandle, CollHandle: ColliderHandle>
     PredictedImpacts<N, Handle, CollHandle>
 {
     fn unwrap_impacts(self) -> (Vec<TOIEntry<N, Handle, CollHandle>>, HashMap<Handle, N>) {
@@ -41,7 +41,7 @@ impl<N: RealField, Handle: BodyHandle, CollHandle: ColliderHandle>
     }
 }
 
-struct SubstepState<N: RealField, Handle: BodyHandle> {
+struct SubstepState<N: RealField + Copy, Handle: BodyHandle> {
     active: bool,
     dt: N,
     end_time: N,
@@ -52,7 +52,7 @@ struct SubstepState<N: RealField, Handle: BodyHandle> {
 }
 
 /// The physics world.
-pub struct MechanicalWorld<N: RealField, Handle: BodyHandle, CollHandle: ColliderHandle> {
+pub struct MechanicalWorld<N: RealField + Copy, Handle: BodyHandle, CollHandle: ColliderHandle> {
     /// Performance counters used for debugging and benchmarking nphysics.
     pub counters: Counters,
     /// The constraints solver.
@@ -67,7 +67,7 @@ pub struct MechanicalWorld<N: RealField, Handle: BodyHandle, CollHandle: Collide
     substep: SubstepState<N, Handle>,
 }
 
-impl<N: RealField, Handle: BodyHandle, CollHandle: ColliderHandle>
+impl<N: RealField + Copy, Handle: BodyHandle, CollHandle: ColliderHandle>
     MechanicalWorld<N, Handle, CollHandle>
 {
     /// Creates a new physics world with default parameters.
@@ -908,7 +908,7 @@ impl<N: RealField, Handle: BodyHandle, CollHandle: ColliderHandle>
     }
 }
 
-struct TOIEntry<N: RealField, Handle, CollHandle> {
+struct TOIEntry<N: RealField + Copy, Handle, CollHandle> {
     toi: N,
     c1: CollHandle,
     b1: Handle,
@@ -918,7 +918,7 @@ struct TOIEntry<N: RealField, Handle, CollHandle> {
     timestamp: usize,
 }
 
-impl<N: RealField, Handle: BodyHandle, CollHandle: ColliderHandle> TOIEntry<N, Handle, CollHandle> {
+impl<N: RealField + Copy, Handle: BodyHandle, CollHandle: ColliderHandle> TOIEntry<N, Handle, CollHandle> {
     fn new(
         toi: N,
         c1: CollHandle,
@@ -1031,22 +1031,22 @@ impl<N: RealField, Handle: BodyHandle, CollHandle: ColliderHandle> TOIEntry<N, H
     }
 }
 
-impl<N: RealField, CollHandle, BodyHandle> PartialOrd for TOIEntry<N, CollHandle, BodyHandle> {
+impl<N: RealField + Copy, CollHandle, BodyHandle> PartialOrd for TOIEntry<N, CollHandle, BodyHandle> {
     fn partial_cmp(&self, other: &Self) -> Option<std::cmp::Ordering> {
         (-self.toi).partial_cmp(&(-other.toi))
     }
 }
 
-impl<N: RealField, CollHandle, BodyHandle> Ord for TOIEntry<N, CollHandle, BodyHandle> {
+impl<N: RealField + Copy, CollHandle, BodyHandle> Ord for TOIEntry<N, CollHandle, BodyHandle> {
     fn cmp(&self, other: &Self) -> std::cmp::Ordering {
         self.partial_cmp(other).unwrap()
     }
 }
 
-impl<N: RealField, CollHandle, BodyHandle> PartialEq for TOIEntry<N, CollHandle, BodyHandle> {
+impl<N: RealField + Copy, CollHandle, BodyHandle> PartialEq for TOIEntry<N, CollHandle, BodyHandle> {
     fn eq(&self, other: &Self) -> bool {
         self.toi == other.toi
     }
 }
 
-impl<N: RealField, CollHandle, BodyHandle> Eq for TOIEntry<N, CollHandle, BodyHandle> {}
+impl<N: RealField + Copy, CollHandle, BodyHandle> Eq for TOIEntry<N, CollHandle, BodyHandle> {}
